# Generated by Django 4.0.10 on 2023-06-22 04:52

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0005_alter_wormhole_archived_at_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='clear',
            name='system',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evesolarsystem', verbose_name='Solar System'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='system',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evesolarsystem', verbose_name='Solar System'),
        ),
    ]
