{% extends "drifters/base.html" %}
{% block details %}
    <div class="col-lg-12">
        <div class="card">
            <div class="card-header">
                <div class="card-header">{{ region }}</div>
            </div>
            <div class="card-body">
                {% for system in scout_system_renders %}{{ system }}{% endfor %}
            </div>
        </div>
    </div>
{% endblock details %}
