# Generated by Django 4.2.6 on 2023-11-03 13:17

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('drifters', '0007_alter_clear_options_driftersconfiguration'),
    ]

    operations = [
        migrations.AddField(
            model_name='driftersconfiguration',
            name='motd_systems',
            field=models.ManyToManyField(related_name='+', to='eveuniverse.evesolarsystem', verbose_name='Systems to be included in the MOTD Generation'),
        ),
        migrations.AlterField(
            model_name='clear',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Created By User'),
        ),
        migrations.AlterField(
            model_name='clear',
            name='updated_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Updated By User'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='POI_regions',
            field=models.ManyToManyField(related_name='+', to='eveuniverse.everegion', verbose_name='POI Regions to be highlighted in the Web UI'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='POI_systems',
            field=models.ManyToManyField(related_name='+', to='eveuniverse.evesolarsystem', verbose_name='POI Systems to be highlighted in the Web UI'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='archived',
            field=models.BooleanField(default=False, verbose_name='Archived'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='archived_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Archived By User'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='complex',
            field=models.CharField(choices=[('Barbican', 'Barbican'), ('Conflux', 'Conflux'), ('Redoubt', 'Redoubt'), ('Sentinel', 'Sentinel'), ('Vidette', 'Vidette'), ('Thera', 'Thera'), ('Turnur', 'Turnur')], max_length=50, verbose_name='Complex'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='created_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Created By User'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='updated_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Update By User'),
        ),
    ]
