# Generated by Django 4.0.10 on 2023-05-31 04:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0004_wormhole_bookmarked_k_wormhole_bookmarked_w_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wormhole',
            name='archived_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='eol_changed_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
