# Generated by Django 4.0.10 on 2023-05-30 12:55

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0003_wormhole_archived_wormhole_archived_at_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='wormhole',
            name='bookmarked_k',
            field=models.BooleanField(default=True, verbose_name='K Space Bookmarked'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='wormhole',
            name='bookmarked_w',
            field=models.BooleanField(default=True, verbose_name='W Space Bookmarked'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='wormhole',
            name='eol_changed_at',
            field=models.DateTimeField(default=datetime.datetime(2023, 5, 30, 12, 55, 59, 850235)),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='archived_at',
            field=models.DateTimeField(blank=True),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='updated_at',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
