# Generated by Django 4.2.6 on 2023-11-03 16:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0008_driftersconfiguration_motd_systems_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='wormhole',
            name='reserved',
            field=models.BooleanField(default=False, verbose_name='Not Published / Reserved for Fleets and WH Team Usage'),
        ),
    ]
