# Generated by Django 4.2.28 on 2026-03-02 11:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0013_alter_clear_system_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='wormhole',
            old_name='system',
            new_name='solar_system',
        ),
    ]
