# Generated by Django 4.2.28 on 2026-03-02 11:29

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eve_sde', '0017_remove_itemtype_market_group_id_raw'),
        ('drifters', '0012_alter_driftersconfiguration_poi_regions_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='clear',
            name='system',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eve_sde.solarsystem', verbose_name='Solar System'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='POI_regions',
            field=models.ManyToManyField(blank=True, related_name='+', to='eve_sde.region', verbose_name='POI Regions to be highlighted in the Web UI'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='POI_systems',
            field=models.ManyToManyField(blank=True, related_name='+', to='eve_sde.solarsystem', verbose_name='POI Systems to be highlighted in the Web UI'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='motd_systems',
            field=models.ManyToManyField(blank=True, related_name='+', to='eve_sde.solarsystem', verbose_name='Systems to be included in the MOTD Generation'),
        ),
        migrations.AlterField(
            model_name='wormhole',
            name='system',
            field=models.ForeignKey(limit_choices_to={'name__in': ['Bazadod', 'Chibi', 'Defsunun', 'Esubara', 'Fihrneh', 'Hoseen', 'Huna', 'Isid', 'Nema', 'Nouta', 'Pserz', 'Soza', 'Aivonen', 'Enaluri', 'Hykanima', 'Ikoskio', 'Immuri', 'Innia', 'Nisuwa', 'Onnamon', 'Raihbaka', 'Rakapas', 'Teskanen', 'Uchomida', 'Anka', 'Ayeroilen', 'Hakodan', 'Haras', 'Huola', 'Iesa', 'Kamela', 'Komaa', 'Kourmonen', 'Kuomi', 'Kurniainen', 'Myyhera', 'Netsalakka', 'Otelen', 'Sahtogas', 'Saidusairos', 'Saikamon', 'Sasiekko', 'Satalama', 'Sosala', 'Tuomuta', 'Uusanen', '2B7A-3', '4DTQ-K', '52G-NZ', 'AH-B84', 'BU-IU4', 'C-LP3N', 'C-VGYO', 'CX-1XF', 'I-7JR4', 'J52-BH', 'KMC-WI', 'LRWD-B', 'M-HU4V', 'NEH-CS', 'O-JPKH', 'P7Z-R3', 'Q-NJZ4', 'SVB-RE', 'T-Q2DD', 'W-4FA9', 'YG-82V', 'Z-K495', '0LY-W1', 'I6-SYN', 'JZ-B5Y', 'LMM7-L', 'M-CNUD', 'NG-M8K', 'U-QMOA', 'U93O-A', '25S-6P', '3GD6-8', '4-07MU', '7LHB-Z', '9-8GBA', 'AX-DOT', 'B-XJX4', 'E3-SDZ', 'EX-0LQ', 'F4R2-Q', 'F9E-KX', 'G-AOTH', 'GE-94X', 'I-8D0G', 'IS-R7P', 'JA-O6J', 'JWZ2-V', 'L7XS-5', 'OGL8-Q', 'SNFV-I', 'ZQ-Z3Y', 'Aikoro', 'Hasama', 'Hysera', 'Irjunen', 'Ishomilken', 'Isutaka', 'Kaunokka', 'Kausaaja', 'Komo', 'Konola', 'Kulelen', 'Kusomonmon', 'Laah', 'Onatoh', 'Sankkasen', 'Santola', 'Tama', 'Uotila', 'Yashunen', '28O-JY', '6-4V20', '77-KDQ', '8R-RTB', 'G8AD-C', 'MJYW-3', 'O-IVNH', 'OU-X3P', 'QA1-BT', 'X-M9ON', 'XT-R36', '1GT-MA', '5E-EZC', '5ED-4E', '5HN-D6', '87-1PM', 'CHP-76', 'DK0-N8', 'E-B957', 'E-BYOS', 'FV-YEA', 'FV1-RQ', 'HB-5L3', 'L-Z9NB', 'X-41DA', 'Y-RAW3', 'Afivad', 'Ana', 'Arbaz', 'Ardishapur Prime', 'Ashab', 'Avair', 'Boranai', 'Cailanar', 'Ebidan', 'Ebtesham', 'Erzoh', 'Esteban', 'Fabin', 'Faswiba', 'Galeh', 'Hadonoo', 'Hutian', 'Jambu', 'Joppaya', 'Knophtikoo', 'Murzi', 'Nadohman', 'Nakri', 'Nifshed', 'Nomash', 'Rimbah', 'Seiradih', 'Sharji', 'Shuria', 'Sobenah', 'Somouh', 'Valmu', 'Yeeramoun', 'Yuhelia', 'ES-UWY', 'G-G78S', 'J7A-UR', 'K-MGJ7', 'V7D-JD', 'Y-K50G', '33RB-O', '3JN9-Q', '5W3-DG', 'E-FIC0', 'MXX5-9', 'MZ1E-P', 'N-TFXK', 'S-DN5M', 'TXME-A', 'U-TJ7Y', 'XCBK-X', 'ZOYW-O', '8F-TK3', 'D-W7F0', 'F-9PXR', 'HM-XR2', 'IP6V-X', 'KBAK-I', 'M-SRKS', 'QY6-RK', 'YZ9-F6', 'Z3V-1W', 'ZXB-VC', 'Zaimeth', 'Ziona', 'Abha', 'Agha', 'Akhrad', 'Asabona', 'Asghatil', 'Bayuka', 'Bekirdod', 'Faspera', 'Fovihi', 'Hahyil', 'Hasateem', 'Ihal', 'Juddi', 'Kuharah', 'Moh', 'Nimambal', 'Ordize', 'Salashayama', 'Sasta', 'Sendaya', 'Serad', 'Shach', 'Shala', 'Shamahi', 'Shenela', 'Uplingur', 'Yuzier', '15U-JY', '6F-H3W', '7BX-6F', '7X-02R', '87XQ-0', 'A-HZYL', 'AC2E-3', 'CHA2-Q', 'G-UTHL', 'H-S80W', 'HMF-9D', 'I-CUVX', 'IGE-RI', 'JGOW-Y', 'KCT-0A', 'L-1SW8', 'P5-EFH', 'PXF-RF', 'Q-XEB3', 'R3W-XU', 'SPLE-Y', 'UAYL-F', 'V6-NY1', 'YRNJ-8', 'Z-YN5Y', 'Z9PP-H', '6EK-BV', 'C-PEWN', 'CR-0E5', 'D-FVI7', 'F-UVBV', 'G-4H4C', 'G-YZUX', 'G2-INZ', 'HHE5-L', 'IPX-H5', 'JAUD-V', 'NIZJ-0', 'P9F-ZG', 'PE-H02', 'Q1-R7K', 'R-ARKN', 'SN9S-N', 'YRV-MZ', '0-G8NO', '1KAW-T', '3-LJW3', '4NDT-W', '5J4K-9', '62O-UE', '7-A6XV', '9-02G0', '9N-0HF', 'BOZ1-O', 'D-0UI0', 'E51-JE', 'GC-LTF', 'GR-X26', 'I-9GI1', 'L-QQ6P', 'L8-WNE', 'NB-ALM', 'P7MI-T', 'PQRE-W', 'RZ-PIY', 'S-51XG', 'SY-UWN', 'T-0JWP', 'TYB-69', 'U-MFTL', 'XA5-TY', 'Z-2Y2Y', 'Arayar', 'Arzad', 'Dihra', 'Hakshma', 'Halenan', 'Itsyamil', 'Mendori', 'Nidebora', 'Odin', 'Raa', 'Roushzar', 'Sosan', 'Thakala', 'Adrel', 'Algogille', 'Andole', 'Arant', 'Arnon', 'Charmerout', 'Haine', 'Heydieles', 'Hulmate', 'Isenan', 'Mesybier', 'Vifrevaert', 'Wysalan', '1PF-BC', '3IK-7O', '4-QDIX', '89-JPE', '8KE-YS', '9P-870', 'CT8K-0', 'F69O-M', 'IRD-HU', 'KGT3-6', 'KMH-J1', 'RO-0PZ', 'WPV-JN', 'Amattens', 'Antollare', 'Athinard', 'Cherore', 'Leremblompes', 'Marosier', 'Mormoen', 'Mya', 'Scuelazyns', '0-ARFO', 'O1Y-ED', 'X36Y-G', '2-F3OE', '2UK4-N', '3-BADZ', '6O-XIO', 'CL-J9W', 'DUU1-K', 'I9-ZQZ', 'K-X5AX', 'OXC-UL', 'P8-BKO', 'PO-3QW', 'QK-CDG', 'U-BXU9', 'UB5Z-3', 'UD-VZW', 'X6-J6R', 'Z-PNIA', 'ZID-LE', 'Ahtulaima', 'Akkio', 'Akora', 'Jakanerva', 'Mahtista', 'Nomaa', 'Nuken', 'Obanen', 'Ohkunen', 'Osaa', 'Otomainen', 'Outuni', 'Shihuken', 'Ukkalen', 'Uoyonen', '39-DGG', '4-CUM5', '4K0N-J', '6L78-1', 'B-F1MI', 'BWF-ZZ', 'D-I9HJ', 'FDZ4-A', 'HKYW-T', 'K42-IE', 'L-TOFR', 'LX-ZOJ', 'O2O-2X', 'QKTR-L', 'SR-KBB', 'TDE4-H', 'TJM-JJ', 'WH-2EZ', 'Access', 'Central Point', 'Chamja', 'Dom-Aphis', 'Habu', 'Hadji', 'Hesarid', 'Madomi', 'Malma', 'Nasreri', 'New Eden', 'Ourapheh', 'Pashanai', 'Sibe', 'Sigga', 'Simela', 'Tahli', 'Vecamia', '4M-P1I', '7Q-8Z2', '8DL-CP', 'B-VIP9', 'DE71-9', 'F5-CGW', 'HB-1NJ', 'IX8-JB', 'N-RAEL', 'NE-3GR', 'QM-20X', 'QQ3-YI', 'R-ESG0', 'TET3-B', 'UNJ-GX', 'UT-UZB', 'V89M-R', 'Y4-GQV', 'YUY-LM', 'ZM-DNR', 'Abudban', 'Ameinaka', 'Bogelek', 'Bosboger', 'Eystur', 'Frarn', 'Krilmokenur', 'Larkugei', 'Obrolber', 'Otraren', 'Rokofur', 'Sist', '6-I162', 'AC-7LZ', 'CJNF-J', 'FRTC-5', 'NS2L-4', 'O7-7UX', 'R-ORB7', 'U9U-TQ', 'Y-C4AL', 'Y-FZ5N', 'Y19P-1', '01TG-J', '4OIV-X', '6E-MOW', 'DDI-B7', 'DY-40Z', 'E7VE-V', 'GU-9F4', 'PZMA-E', 'X-0CKQ', 'Z-N9IP', '3Q-VZA', '4-EFLU', '5NQI-E', '8-OZU1', 'EIH-IU', 'G9L-LP', 'GPD5-0', 'HD-AJ7', 'HPBE-D', 'J-RXYN', 'J7-BDX', 'JEQG-7', 'JQU-KY', 'R0-DMM', 'U104-3', 'Aharalel', 'Ansasos', 'Ardhis', 'Asrios', 'Bersyrim', 'Chanoun', 'Halibai', 'Hikansog', 'Hiremir', 'Ithar', 'Jennim', 'Miah', 'Oberen', 'Peyiri', 'Rayeret', 'Salah', 'Ustnia', '0-VG7A', '1ZF-PJ', '4CJ-AC', '5-2PQU', '5C-RPA', '88A-RA', 'B-II34', 'C1G-XC', 'EKPB-3', 'EUU-4N', 'F3-8X2', 'F39H-1', 'GDHN-K', 'GK5Z-T', 'HL-VZX', 'KD-KPR', 'L5-UWT', 'MOCW-2', 'N-O53U', 'N7-BIY', 'O-7LAI', 'RD-FWY', 'V-QXXK', 'VBPT-T', 'XQP-9C', 'ZO-4AR', 'Arzieh', 'Ashmarir', 'Aurejet', 'Dimoohan', 'Fanathor', 'Firbha', 'Gidali', 'Hishai', 'Kuhri', 'Moro', 'Nahrneder', 'Nakis', 'Parses', 'Reteka', 'Sassecho', 'Sazre', 'Seshala', 'Talidal', 'Tzashrah', 'Zahefeus', '6FS-CZ', '86L-9F', 'BM-VYZ', 'BVRQ-O', 'C3J0-O', 'EPCD-D', 'HD-HOZ', 'HPV-RJ', 'J-OAH2', 'JT2I-7', 'K76A-3', 'LE-67X', 'R1O-GN', 'SH6X-F', 'TA9T-P', 'Aivoli', 'Ajanen', 'Ekura', 'Hakonen', 'Isseras', 'Kirras', 'Korama', 'Oishami', 'Ossa', 'Rauntaka', 'Ruvas', 'Sotrentaira', 'Tartoken', 'Tunttaras', 'Vuorrassi', 'Yoma', 'Amdonen', 'Ami', 'Andrub', 'Annad', 'Choga', 'Fensi', 'Khabara', 'Kizama', 'Kor-Azor Prime', 'Leva', 'Masanuh', 'Mora', 'Nahol', 'Nahyeen', 'Nakregde', 'Nibainkier', 'Nishah', 'Ordion', 'Perbhe', 'Rannoze', 'Shaha', 'Shokal', 'Tralasa', 'Zatamaka', 'Zorenyen', 'Agtver', 'Aldilur', 'Ardar', 'Arifsdald', 'Arnstur', 'Aset', 'Asgeir', 'Atonder', 'Auner', 'Earwik', 'Egbonbet', 'Egmar', 'Eram', 'Erindur', 'Erstet', 'Erstur', 'Eszur', 'Eygfe', 'Fildar', 'Hakeri', 'Hilfhurmur', 'Hjoramold', 'Hodrold', 'Jondik', 'Lasleinur', 'Lirerim', 'Nakugard', 'Nedegulf', 'Sirekur', 'Situner', 'Tabbetzur', '1NZV-7', '7T-0QS', 'APES-G', 'DAI-SH', 'F-TQWO', 'GL6S-2', 'H-EBQG', 'HG-YEQ', 'IBOX-2', 'JA-G0T', 'N-YLOE', 'NBW-GD', 'NSI-MW', 'POQP-K', 'PWPY-4', 'QSCO-D', 'RUF3-O', 'S5W-1Z', 'VVB-QH', 'XTVZ-E', 'Y-XZA7', 'ZOPZ-6', '3-JG3X', '6U-MFQ', 'DGDT-3', 'HO4E-Q', 'IG-4OF', 'IO-R2S', 'JXQJ-B', 'KED-2O', 'MZLW-9', 'RJBC-I', 'U-RELP', 'U9SE-N', 'X-CYNC', 'X-Z4JW', 'XKM-DE', 'Y-770C', 'Altbrard', 'Gulfonodi', 'Hedaleolfarber', 'Hegfunden', 'Hrokkur', 'Illamur', 'Orien', 'Osvetur', 'Sakulda', 'Varigne', '7-8EOE', '99-0GS', '9MWZ-B', 'C-WPWH', 'DJK-67', 'H90-C9', 'KR8-27', 'L-AS00', 'M9-FIB', 'OKEO-X', 'X-EHHD', 'Z-7OK1', '0-4VQL', '2ULC-J', '2WU-XT', '4AZV-W', '4O-ZRI', '8-AA98', 'CNHV-M', 'J7X-VN', 'KGCF-5', 'MC4C-H', 'N-I024', 'QFRV-2', 'QHH-13', 'QOK-SX', 'TFPT-U', 'WIO-OL', 'XUPK-Z', 'YQM-P1', 'ZZK-VF', '0-WVQS', '0D-CHA', 'A-5M31', 'C0T-77', 'CT7-5V', 'F5FO-U', 'JKJ-VJ', 'T-Z6J2', '3PPT-9', 'ARBX-9', 'GQ2S-8', 'H8-ZTO', 'LD-2VL', 'O-MCZR', 'O-N589', '0-U2M4', '4-1ECP', '9-ZA4Z', 'A1F-22', 'BEG-RL', 'E-WMT7', 'H-29TM', 'J9A-BH', 'JPEZ-R', 'JZ-UQC', 'LW-YEW', 'M4-KX5', 'MJ-5F9', 'MTO2-2', 'O-QKSM', 'OP7-BP', 'PE-SAM', 'PFV-ZH', 'RY-2FX', 'SY-OLX', 'TAL1-3', 'VWES-Y', 'XU7-CH', '08S-39', 'E-DOF2', 'RYQC-I', 'TCAG-3', 'VQE-CN', 'Z-M5A1', 'Adiere', 'Adrallezoen', 'Alles', 'Augnais', 'Aunia', 'Balle', 'Bamiette', 'Basgerin', 'Colelie', 'Crielere', 'Croleur', 'Doussivitte', 'Dunraelare', 'Eglennaert', 'Fluekele', 'Gallareue', 'Iyen-Oursta', 'Lamadent', 'Lermireve', 'Pucherie', 'Sharuveil', 'Stegette', 'Unel', 'Algasienan', 'Alsavoinon', 'Amoen', 'Aubonnie', 'Aulbres', 'Cumemare', 'Dastryns', 'Evaulon', 'Gallusiene', 'Mercomesier', 'Moclinamaud', 'Oicx', 'Pain', '1QZ-Y9', '2-KPW6', '4E-EZS', '6-KPAB', '9PX2-F', 'F2-NXA', 'FYD-TO', 'GN-PDU', 'H5N-V7', 'IAK-JW', 'JLO-Z3', 'K7-LDX', 'LBC-AW', 'LQ-OAI', 'NSBE-L', 'Q-K2T7', 'Q-NA5H', 'U2-28D', 'V-F6DQ', 'WFFE-4', 'WV0D-1', 'X9V-15', '2V-CS5', '8P9-BM', '9UY4-H', 'D-6WS1', 'FSW-3C', 'GN7-XY', 'HP-6Z6', 'I-MGAB', 'K1Y-5H', 'MH9C-S', 'N-RMSH', 'OXIY-V', 'QBL-BV', 'QR-K85', 'TU-O0T', 'Aeter', 'Anckee', 'Maire', 'Odinesyn', 'Ogaria', 'Pertnineere', 'Stoure', 'Toustain', 'Weraroix', 'Yvelet', '2B-3M4', '2IGP-1', '373Z-7', '37S-KO', '42-UOW', '4XW2-D', '6QBH-S', 'A-GPTM', 'B-G1LG', 'CJF-1P', 'FV-SE8', 'G-ME2K', 'J-AYLV', 'JU-UYK', 'L6B-0N', 'LGK-VP', 'LGL-SD', 'O-CT8N', 'TL-T9Z', 'UKYS-5', 'WEQT-K', 'WHG2-7', 'X5O1-L', 'XFBE-T', 'Y1-UQ2', '12YA-2', '4-ABS8', '5ZXX-K', 'JC-YX8', 'KQK1-2', 'R-2R0G', 'RORZ-H', 'RZC-16', 'S-MDYI', 'U-INPD', 'UC3H-Y', 'UI-8ZE', 'WW-KGD', 'B9EA-G', 'C6C-K9', 'E-BFLT', 'ETO-OT', 'GTB-O4', 'H4X-0I', 'HIK-MC', 'K-XJJT', 'K-YL9T', 'KPI-OW', 'M-NP5O', 'OTJ9-E', 'P65-TA', 'RXA-W1', '0-XIDJ', '2PLH-3', '4RX-EE', '9-266Q', '92K-H2', '9IPC-E', 'AJCJ-1', 'EK2-ET', 'HBD-CC', 'K3JR-J', 'M2-2V1', 'N-Q5PW', 'N5Y-4N', 'OJ-CT4', 'Y6-HPG', '3D5K-R', '8B-SAJ', 'A-BO4V', 'A3-LOG', 'E-VKJV', 'ED-L9T', 'KEJY-U', 'MKD-O8', 'O3L-95', 'OGY-6D', 'RF-CN3', 'TV8-HS', 'UVHO-F', 'UYU-VV', 'W6V-VM', 'Z-UZZN', '0LTQ-C', '2G38-I', '5-FGQI', '5-T0PZ', '5-VKCN', '51-5XG', '57-YRU', '6-CZ49', '617I-I', '9U-TTJ', 'BY-S36', 'CIS-7X', 'DUV-5Y', 'EU0I-T', 'FD-MLJ', 'KFR-ZE', 'Poitot', 'T-LIWS', 'ZN0-SR', 'Abai', 'Adahum', 'Ahkour', 'Ahrosseas', 'Arakor', 'Chamume', 'Gyerzen', 'Hilaban', 'Hoona', 'Ivih', 'Kerepa', 'Lari', 'Mani', 'Paye', 'Pera', 'Phoren', 'Pimsu', 'Remoriu', 'Rumida', 'Safilbab', 'Saminer', 'Teshkat', 'Tew', 'Yeder', '3DR-CR', '5-O8B1', '6OYQ-Z', '7D-PAT', 'A1RR-M', 'EOY-BG', 'KMV-CQ', 'PNS7-J', 'Q1U-IU', 'S-1LIO', 'SZ6-TA', 'T-K10W', 'WV-0R2', 'ZK-YQ3', '0P-U0Q', '16AM-3', '3L3N-X', '9-980U', 'BW-WJ2', 'F-ZBO0', 'FE-6YQ', 'H-HWQR', 'JI1-SY', 'KW-OAM', 'MS1-KJ', 'NZW-ZO', 'PEK-8Z', 'T-AKQZ', 'WB-AYY', 'Y-EQ0C', 'Y-ORBJ', 'ZD1-Z2', 'ZO-P5K', 'C2X-M5', 'C8VC-S', 'F-749O', 'NJ4X-S', 'S8-NSQ', 'SH1-6P', 'V0DF-2', 'W-UQA5', 'WH-JCA', 'XD-TOV', '0MV-4W', '1N-FJ8', '1VK-6B', '1W-0KS', '5T-KM3', '6WW-28', '7-K5EL', 'BR-6XP', 'FS-RFL', 'H-NOU5', 'JZV-F4', 'LS9B-9', 'MGAM-4', 'MQ-O27', 'O-LR1H', 'P3EN-E', 'Q-R3GP', 'S-NJBB', 'VI2K-J', 'XSQ-TF', 'Z-8Q65', 'ZA0L-U', 'Adallier', 'Alenia', 'Arraron', 'Channace', 'Claulenne', 'Merolles', 'Raneilles', 'Scolluzer', 'Tierijev']}, on_delete=django.db.models.deletion.CASCADE, to='eve_sde.solarsystem', verbose_name='Solar System'),
        ),
    ]
