# Generated by Django 4.2.6 on 2023-11-01 05:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0006_alter_clear_system_alter_wormhole_system'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='clear',
            options={'verbose_name': 'Clear System', 'verbose_name_plural': 'Clear Systems'},
        ),
        migrations.CreateModel(
            name='DriftersConfiguration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('POI_regions', models.ManyToManyField(related_name='+', to='eveuniverse.everegion', verbose_name='POI Regions')),
                ('POI_systems', models.ManyToManyField(related_name='+', to='eveuniverse.evesolarsystem', verbose_name='POI Systems')),
            ],
            options={
                'verbose_name': 'Drifters Configuration',
                'default_permissions': (),
            },
        ),
    ]
