# Generated by Django 4.0.10 on 2023-05-30 08:58

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Wormhole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('complex', models.CharField(choices=[('Barbican', 'Barbican'), ('Conflux', 'Conflux'), ('Redoubt', 'Redoubt'), ('Sentinel', 'Sentinel'), ('Vidette', 'Vidette')], max_length=50, verbose_name='Complex')),
                ('mass', models.CharField(choices=[('Fresh', 'This wormhole has not yet had its stability significantly disrupted by ships passing through it'), ('Reduced', 'This wormhole has had its stability reduced by ships passing through it, but not to a critical degree yet'), ('Critical', 'This wormhole has had its stability critically disrupted by the mass of numerous ships passing through and is on the verge of collapse')], max_length=50, verbose_name='Mass Remaining')),
                ('lifetime', models.CharField(choices=[('Fresh', 'This wormhole has not yet begun its natural cycle of decay and should last at least another day'), ('Decaying', "This wormhole is beginning to decay, and probably won't last another day"), ('EOL', 'This wormhole is reaching the end of its natural lifetime')], max_length=50, verbose_name='Lifetime Remaining')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='')),
                ('system', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evesolarsystem', verbose_name='')),
                ('updated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='')),
            ],
            options={
                'verbose_name': 'Wormhole',
                'verbose_name_plural': 'Wormholes',
            },
        ),
    ]
