{% load i18n %}
{% load drifters %}
<div class="col-lg-4">
    {% if count == update_older_than_12h %}
        <div class="card card-danger">
        {% elif count == update_older_than_8h %}
            <div class="card card-warning">
            {% elif count == update_older_than_4h %}
                <div class="card card-info">
                {% else %}
                    <div class="card card-success">
                    {% endif %}

                    <div class="card-header">
                        <div class="card-header">{{ region }} x {{ count }}</div>
                    </div>
                    <div class="card-body">
                        update_older_than_4h: {{ update_older_than_4h }}
                        <br />
                        update_older_than_8h: {{ update_older_than_8h }}
                        <br />
                        update_older_than_12h: {{ update_older_than_12h }}
                        <br />
                    </div>
                    <div class="card-footer">
                        <a name="Scout" class="btn btn-primary" href={% url "drifters:scout_region" region_id=region.id %} role="button">Scout</a>
                    </div>
                </div>
            </div>
