# Generated by Django 4.0.10 on 2023-05-30 12:19

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('drifters', '0002_clear'),
    ]

    operations = [
        migrations.AddField(
            model_name='wormhole',
            name='archived',
            field=models.BooleanField(blank=True, default=False, null=True, verbose_name='Archived'),
        ),
        migrations.AddField(
            model_name='wormhole',
            name='archived_at',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='wormhole',
            name='archived_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name=''),
        ),
    ]
