{% extends "drifters/base.html" %}
{% load i18n %}
{% load humanize %}
{% block details %}
    <div class="row">
        {% for complex in scout_complex_renders %}{{ complex }}{% endfor %}
    </div>
    <div class="row">
        {% for region in scout_region_renders %}{{ region }}{% endfor %}
    </div>
{% endblock details %}
