{% extends "allianceauth/base.html" %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% block page_title %}
    {% translate "Drifters" %}
{% endblock page_title %}
{% block content %}
    <div class="container-fluid aa-drifters">
        <br />
        <nav class="navbar navbar-default">
            <div class="navbar-header">
                <button type="button"
                        class="navbar-toggle collapsed"
                        data-toggle="collapse"
                        data-target="#drifters-navbar-collapse-1"
                        aria-expanded="false">
                    <span class="sr-only">{% translate "Toggle navigation" %}</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="{% url 'drifters:index' %}">{% translate "Drifters" %}</a>
            </div>
            <div class="collapse navbar-collapse" id="drifters-navbar-collapse-1">
                <ul class="nav navbar-nav pull-right">
                    <li>
                        <a href="{% url 'drifters:motd' %}">{% translate "MOTD Generator" %}</a>
                    </li>
                </ul>
                <ul class="nav navbar-nav pull-right">
                    <li>
                        <a href="{% url 'drifters:scout' %}">{% translate "Scout Interface" %}</a>
                    </li>
                </ul>
            </div>
        </nav>
        {% block details %}
        {% endblock details %}
    </div>
{% endblock content %}
