{% if wormhole.region in poi_regions %}
    <span class="badge badge-info">{{ wormhole.region }}</span>
{% else %}
    <span class="badge badge-default">{{ wormhole.region }}</span>
{% endif %}
/
{% if wormhole.system in poi_systems %}
    <span class="badge badge-info">{{ wormhole.system }}</span>
{% else %}
    <span class="badge badge-default">{{ wormhole.system }}</span>
{% endif %}
{% if wormhole.mass == "Fresh" %}
    <span class="badge badge-default">{{ wormhole.mass }}</span>
{% elif wormhole.mass == "Reduced" %}
    <span class="badge badge-warning">{{ wormhole.mass }}</span>
{% elif wormhole.mass == "Critical" %}
    <span class="badge badge-danger">{{ wormhole.mass }}</span>
{% endif %}
{% if wormhole.lifetime == "Fresh" %}
    <span class="badge badge-default">{{ wormhole.formatted_lifetime }}</span>
{% elif wormhole.lifetime == "Decaying" %}
    <span class="badge badge-warning">{{ wormhole.formatted_lifetime }}</span>
{% elif wormhole.lifetime == "EOL" %}
    <span class="badge badge-danger">{{ wormhole.formatted_lifetime }}</span>
{% endif %}
{% if wormhole.bookmarked_k %}<span class="badge badge-default">K</span>{% endif %}
{% if wormhole.bookmarked_w %}<span class="badge badge-default">W</span>{% endif %}
<br />
