# Generated by Django 4.2.16 on 2024-11-26 11:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drifters', '0011_alter_wormhole_managers'),
    ]

    operations = [
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='POI_regions',
            field=models.ManyToManyField(blank=True, related_name='+', to='eveuniverse.everegion', verbose_name='POI Regions to be highlighted in the Web UI'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='POI_systems',
            field=models.ManyToManyField(blank=True, related_name='+', to='eveuniverse.evesolarsystem', verbose_name='POI Systems to be highlighted in the Web UI'),
        ),
        migrations.AlterField(
            model_name='driftersconfiguration',
            name='motd_systems',
            field=models.ManyToManyField(blank=True, related_name='+', to='eveuniverse.evesolarsystem', verbose_name='Systems to be included in the MOTD Generation'),
        ),
    ]
