{% extends "drifters/base.html" %}
{% load bootstrap %}

{% block details %}
    <div class="col-lg-12">
        <div class="card">
            <div class="card-header">
                <div class="card-header">{{ complex }}</div>
            </div>
            <div class="card-body">
                <form method="post">
                    {% csrf_token %}
                    {{ formset.management_form }}
                    <table>
                        {{ formset }}
                    </table>
                    <button>Add/Save</button>
                </form>
            </div>
        </div>
    </div>
{% endblock details %}
